#ifndef MODEPANEL_H
#define MODEPANEL_H

#include <QWidget>
#include <QPair>

class QComboBox;

class ModePanel : public QWidget
{
    Q_OBJECT

public:
    explicit ModePanel(QWidget *parent = 0, int defaultMode = 1, int defaultAILevel = 1);
    QPair<int, int>  mode() const;
private:
    QComboBox *cbMode_;
    QComboBox *cbStrength_;

};

#endif // MODEPANEL_H
